@@ -45,7 +45,6 @@
 
 typedef enum {
 	ACTIVATION_ACTION_LAUNCH_DESKTOP_FILE,
-	ACTIVATION_ACTION_LAUNCH_APPLICATION_FROM_COMMAND,
 	ACTIVATION_ACTION_ASK,
 	ACTIVATION_ACTION_LAUNCH,
 	ACTIVATION_ACTION_LAUNCH_IN_TERMINAL,
@@ -599,9 +598,9 @@ report_broken_symbolic_link (GtkWindow *parent_window, NautilusFile *file)
 
 	target_path = nautilus_file_get_symbolic_link_target_path (file);
 	if (target_path == NULL) {
-		detail = g_strdup (_("This link can't be used, because it has no target."));
+		detail = g_strdup (_("This link cannot be used, because it has no target."));
 	} else {
-		detail = g_strdup_printf (_("This link can't be used, because its target "
+		detail = g_strdup_printf (_("This link cannot be used, because its target "
 					    "\"%s\" doesn't exist."), target_path);
 	}
 	
@@ -736,6 +735,10 @@ get_activation_action (NautilusFile *file)
 {
 	ActivationAction action;
 	char *activation_uri;
+
+	if (nautilus_file_is_launcher (file)) {
+		return ACTIVATION_ACTION_LAUNCH_DESKTOP_FILE;
+	}
 	
 	activation_uri = nautilus_file_get_activation_uri (file);
 	if (activation_uri == NULL) {
@@ -743,12 +746,7 @@ get_activation_action (NautilusFile *file)
 	}
 
 	action = ACTIVATION_ACTION_DO_NOTHING;
-	
-	if (eel_str_has_prefix (activation_uri, NAUTILUS_DESKTOP_COMMAND_SPECIFIER)) {
-		action = ACTIVATION_ACTION_LAUNCH_DESKTOP_FILE;
-	} else if (eel_str_has_prefix (activation_uri, NAUTILUS_COMMAND_SPECIFIER)) {
-		action = ACTIVATION_ACTION_LAUNCH_APPLICATION_FROM_COMMAND;
-	} else if (nautilus_file_is_launchable (file)) {
+	if (nautilus_file_is_launchable (file)) {
 		char *executable_path;
 		
 		action = ACTIVATION_ACTION_LAUNCH;
@@ -793,9 +791,9 @@ mime_application_hash (GAppInfo *app)
 	id = g_app_info_get_id (app);
 
 	if (id == NULL) {
-		return (guint) app;
+		return GPOINTER_TO_UINT(app);
 	}
-	
+
 	return g_str_hash (id);
 }
 
@@ -1004,7 +1002,6 @@ activate_files (ActivateParameters *parameters)
 {
 	NautilusFile *file;
 	GList *launch_desktop_files;
-	GList *launch_from_command_files;
 	GList *launch_files;
 	GList *launch_in_terminal_files;
 	GList *open_in_app_files;
@@ -1023,7 +1020,6 @@ activate_files (ActivateParameters *parameters)
 	screen = gtk_widget_get_screen (GTK_WIDGET (parameters->parent_window));
 
 	launch_desktop_files = NULL;
-	launch_from_command_files = NULL;
 	launch_files = NULL;
 	launch_in_terminal_files = NULL;
 	open_in_app_files = NULL;
@@ -1048,9 +1044,6 @@ activate_files (ActivateParameters *parameters)
 		case ACTIVATION_ACTION_LAUNCH_DESKTOP_FILE :
 			launch_desktop_files = g_list_prepend (launch_desktop_files, file);
 			break;
-		case ACTIVATION_ACTION_LAUNCH_APPLICATION_FROM_COMMAND :
-			launch_from_command_files = g_list_prepend (launch_from_command_files, file);
-			break;
 		case ACTIVATION_ACTION_LAUNCH :
 			launch_files = g_list_prepend (launch_files, file);
 			break;
@@ -1084,22 +1077,6 @@ activate_files (ActivateParameters *parameters)
 		g_free (uri);
 	}
 
-	launch_from_command_files = g_list_reverse (launch_from_command_files);
-	for (l = launch_from_command_files; l != NULL; l = l->next) {
-		file = NAUTILUS_FILE (l->data);
-
-		uri = nautilus_file_get_activation_uri (file);
-
-		nautilus_debug_log (FALSE, NAUTILUS_DEBUG_LOG_DOMAIN_USER,
-				    "directory view activate_callback launch_application_from_command window=%p: %s",
-				    parameters->parent_window, uri);
-
-		nautilus_launch_application_from_command (
-				screen, NULL, uri + strlen (NAUTILUS_COMMAND_SPECIFIER),
-				NULL, FALSE);
-		g_free (uri);
-	}
-
 	old_working_dir = NULL;
 	if (parameters->activation_directory &&
 	    (launch_files != NULL || launch_in_terminal_files != NULL)) {
@@ -1219,7 +1196,7 @@ activate_files (ActivateParameters *parameters)
 			(full_uri_for_display, MAX_URI_IN_DIALOG_LENGTH);
 		g_free (full_uri_for_display);
 	
-		error_message = g_strdup_printf (_("Couldn't display \"%s\"."),
+		error_message = g_strdup_printf (_("Could not display \"%s\"."),
 						 uri_for_display);
 		
 		g_free (uri_for_display);
@@ -1240,7 +1217,6 @@ activate_files (ActivateParameters *parameters)
 	}
 
 	g_list_free (launch_desktop_files);
-	g_list_free (launch_from_command_files);
 	g_list_free (launch_files);
 	g_list_free (launch_in_terminal_files);
 	g_list_free (open_in_view_files);
@@ -1259,25 +1235,31 @@ activation_mount_not_mounted_callback (GObject *source_object,
 	ActivateParameters *parameters = user_data;
 	GError *error;
 	NautilusFile *file;
+	GFile *location;
 
 	file = parameters->not_mounted->data;
 		
 	error = NULL;
 	if (!g_file_mount_enclosing_volume_finish (G_FILE (source_object), res, &error)) {
-		if (error->domain != G_IO_ERROR &&
-		    error->code != G_IO_ERROR_CANCELLED &&
-		    error->code != G_IO_ERROR_ALREADY_MOUNTED) {
+		if (error->domain != G_IO_ERROR ||
+		    (error->code != G_IO_ERROR_CANCELLED &&
+		     error->code != G_IO_ERROR_FAILED_HANDLED &&
+		     error->code != G_IO_ERROR_ALREADY_MOUNTED)) {
 			eel_show_error_dialog (_("Unable to mount location"),
 					       error->message, NULL);
 		}
 
-		if (error->domain != G_IO_ERROR &&
+		if (error->domain != G_IO_ERROR ||
 		    error->code != G_IO_ERROR_ALREADY_MOUNTED) {
 			parameters->files = g_list_remove (parameters->files, file); 
 			nautilus_file_unref (file);
 		}
 
 		g_error_free (error);
+	} else {
+		location = nautilus_file_get_location (file);
+		nautilus_inhibit_autorun_for_file (location);
+		g_object_unref (G_OBJECT (location));
 	}
 	
 	parameters->not_mounted = g_list_delete_link (parameters->not_mounted,
@@ -1299,7 +1281,6 @@ activation_mount_not_mounted (ActivateParameters *parameters)
 		mount_op = eel_mount_operation_new (parameters->parent_window);
 		g_signal_connect (mount_op, "active_changed", (GCallback)activate_mount_op_active, parameters);
 		location = nautilus_file_get_location (file);
-		nautilus_inhibit_autorun_for_file (location);
 		g_file_mount_enclosing_volume (location, 0, mount_op, parameters->cancellable,
 					       activation_mount_not_mounted_callback, parameters);
 		g_object_unref (location);
@@ -1308,6 +1289,12 @@ activation_mount_not_mounted (ActivateParameters *parameters)
 	}
 
 	parameters->tried_mounting = TRUE;
+
+	if (parameters->files == NULL) {
+		activation_parameters_free (parameters);
+		return;
+	}
+	
 	nautilus_file_list_call_when_ready
 		(parameters->files,
 		 nautilus_mime_actions_get_required_file_attributes () | NAUTILUS_FILE_ATTRIBUTE_LINK_INFO,
@@ -1407,9 +1394,7 @@ activate_activation_uris_ready_callback (GList *files_ignore,
 		 * about the attributes for that, not for the original file.
 		 */
 		uri = nautilus_file_get_activation_uri (file);
-		if (uri != NULL &&
-		    !(g_str_has_prefix (uri, NAUTILUS_DESKTOP_COMMAND_SPECIFIER) ||
-		      g_str_has_prefix (uri, NAUTILUS_COMMAND_SPECIFIER))) {
+		if (uri != NULL) {
 			NautilusFile *actual_file;
 			
 			actual_file = nautilus_file_get_by_uri (uri);
@@ -1493,15 +1478,17 @@ activation_mountable_mounted (NautilusFile  *file,
 	} else {
 		/* Remove failed file */
 		
-		if (error->domain != G_IO_ERROR &&
-		    error->code != G_IO_ERROR_ALREADY_MOUNTED) {
+		if (error->domain != G_IO_ERROR ||
+		    (error->code != G_IO_ERROR_FAILED_HANDLED &&
+		     error->code != G_IO_ERROR_ALREADY_MOUNTED)) {
 			parameters->files = g_list_remove (parameters->files, file); 
 			nautilus_file_unref (file);
 		}
 		
-		if (error->domain != G_IO_ERROR &&
-		    error->code != G_IO_ERROR_CANCELLED &&
-		    error->code != G_IO_ERROR_ALREADY_MOUNTED) {
+		if (error->domain != G_IO_ERROR ||
+		    (error->code != G_IO_ERROR_CANCELLED &&
+		     error->code != G_IO_ERROR_FAILED_HANDLED &&
+		     error->code != G_IO_ERROR_ALREADY_MOUNTED)) {
 			eel_show_error_dialog (_("Unable to mount location"),
 					       error->message, NULL);
 		}
