@@ -48,7 +48,6 @@
 #include <fcntl.h>
 #include <string.h>
 #include "nautilus-desktop-window.h"
-#include "nautilus-first-time-druid.h"
 #include "nautilus-main.h"
 #include "nautilus-spatial-window.h"
 #include "nautilus-navigation-window.h"
@@ -127,8 +126,6 @@ static void     update_session                    (gpointer                  cal
 static void     init_session                      (void);
 static gboolean is_kdesktop_present               (void);
 
-static char    *save_session_to_file              (void);
-
 BONOBO_CLASS_BOILERPLATE (NautilusApplication, nautilus_application,
 			  BonoboGenericFactory, BONOBO_TYPE_GENERIC_FACTORY)
 
@@ -542,7 +539,6 @@ nautilus_application_startup (NautilusApplication *application,
 			      gboolean restart_shell,
 			      gboolean no_default_window,
 			      gboolean no_desktop,
-			      gboolean do_first_time_druid_check,
 			      gboolean browser_window,
 			      const char *startup_id,
 			      const char *geometry,
@@ -602,18 +598,18 @@ nautilus_application_startup (NautilusApplication *application,
 			 * this problem but we don't exactly understand why,
 			 * since neither of the above causes explain it.
 			 */
-			message = _("Nautilus can't be used now. "
+			message = _("Nautilus cannot be used now. "
 				    "Running the command \"bonobo-slay\""
 				    " from the console may fix the problem. If not,"
 				    " you can try rebooting the computer or"
 				    " installing Nautilus again.");
 			/* FIXME bugzilla.gnome.org 42536: The guesses and stuff here are lame. */
-			detailed_message = _("Nautilus can't be used now. "
+			detailed_message = _("Nautilus cannot be used now. "
 					     "Running the command \"bonobo-slay\" "
 					     "from the console may fix the problem. If not, "
 					     "you can try rebooting the computer or "
 					     "installing Nautilus again.\n\n"
-					     "Bonobo couldn't locate the Nautilus_shell.server file. "
+					     "Bonobo could not locate the Nautilus_shell.server file. "
 					     "One cause of this seems to be an LD_LIBRARY_PATH "
 					     "that does not include the bonobo-activation library's directory. "
 					     "Another possible cause would be bad install "
@@ -622,7 +618,7 @@ nautilus_application_startup (NautilusApplication *application,
 					     "Bonobo Activation and GConf processes, which may be needed by "
 					     "other applications.\n\n"
 					     "Sometimes killing bonobo-activation-server and gconfd fixes "
-					     "the problem, but we don't know why.\n\n"
+					     "the problem, but we do not know why.\n\n"
 					     "We have also seen this error when a faulty "
 					     "version of bonobo-activation was installed.");
 			break;
@@ -638,8 +634,8 @@ nautilus_application_startup (NautilusApplication *application,
 			 * current OAF. I guess I read the code wrong. Need to figure out when and make a
 			 * good message.
 			 */
-			message = _("Nautilus can't be used now, due to an unexpected error.");
-			detailed_message = _("Nautilus can't be used now, due to an unexpected error "
+			message = _("Nautilus cannot be used now, due to an unexpected error.");
+			detailed_message = _("Nautilus cannot be used now, due to an unexpected error "
 					     "from Bonobo when attempting to register the file manager view server.");
 			break;
 		}
@@ -656,15 +652,15 @@ nautilus_application_startup (NautilusApplication *application,
 			 */
 			if (result == Bonobo_ACTIVATION_REG_SUCCESS) {
 				/* FIXME bugzilla.gnome.org 42538: When can this happen? */
-				message = _("Nautilus can't be used now, due to an unexpected error.");
-				detailed_message = _("Nautilus can't be used now, due to an unexpected error "
+				message = _("Nautilus cannot be used now, due to an unexpected error.");
+				detailed_message = _("Nautilus cannot be used now, due to an unexpected error "
 						     "from Bonobo when attempting to locate the factory. "
 						     "Killing bonobo-activation-server and restarting Nautilus may help fix the problem.");
 			} else {
 				num_failures++;
 				if (num_failures > 20) {
-					message = _("Nautilus can't be used now, due to an unexpected error.");
-					detailed_message = _("Nautilus can't be used now, due to an unexpected error "
+					message = _("Nautilus cannot be used now, due to an unexpected error.");
+					detailed_message = _("Nautilus cannot be used now, due to an unexpected error "
 							     "from Bonobo when attempting to locate the shell object. "
 							     "Killing bonobo-activation-server and restarting Nautilus may help fix the problem.");
 					
@@ -1539,8 +1535,8 @@ icon_from_string (const char *string)
 	return NULL;
 }
 
-static char *
-save_session_to_file (void)
+char *
+nautilus_application_save_session_to_file (void)
 {
 	xmlDocPtr doc;
 	xmlNodePtr root_node, history_node;
@@ -1834,7 +1830,7 @@ save_session (GnomeClient *client, gint phase, GnomeSaveStyle save_style, gint s
 
 	argv[0] = "nautilus";
 
-	argv[2] = save_session_to_file ();
+	argv[2] = nautilus_application_save_session_to_file ();
 	if (argv[2] != NULL) {
 		argv[1] = "--load-session";
 	}
