@@ -56,6 +56,7 @@
 #include <libnautilus-private/nautilus-file-operations.h>
 #include <libnautilus-private/nautilus-trash-monitor.h>
 #include <libnautilus-private/nautilus-icon-names.h>
+#include <libnautilus-private/nautilus-autorun.h>
 #include <gio/gio.h>
 
 #include "nautilus-bookmark-list.h"
@@ -294,6 +295,16 @@ update_places (NautilusPlacesSidebar *sidebar)
 		gtk_tree_selection_select_iter (selection, &last_iter);
 	}
 
+ 	mount_uri = "network:///"; /* No need to strdup */
+	icon = g_themed_icon_new (NAUTILUS_ICON_NETWORK);
+	last_iter = add_place (sidebar, PLACES_BUILT_IN,
+			       _("Network"), icon,
+			       mount_uri, NULL, NULL, NULL, 0);
+	g_object_unref (icon);
+	if (strcmp (location, mount_uri) == 0) {
+		gtk_tree_selection_select_iter (selection, &last_iter);
+	}
+
 	volume_monitor = sidebar->volume_monitor;
 
 	/* first go through all connected drives */
@@ -342,6 +353,7 @@ update_places (NautilusPlacesSidebar *sidebar)
 				}
 				g_object_unref (volume);
 			}
+			g_list_free (volumes);
 		} else {
 			if (g_drive_is_media_removable (drive) && !g_drive_is_media_check_automatic (drive)) {
 				/* If the drive has no mountable volumes and we cannot detect media change.. we
@@ -1313,7 +1325,7 @@ open_selected_bookmark (NautilusPlacesSidebar *sidebar,
 		GVolume *volume;
 		gtk_tree_model_get (model, &iter, PLACES_SIDEBAR_COLUMN_VOLUME, &volume, -1);
 		if (volume != NULL) {
-			nautilus_file_operations_mount_volume (NULL, volume);
+			nautilus_file_operations_mount_volume (NULL, volume, TRUE);
 			g_object_unref (volume);
 		}
 	}
@@ -1428,7 +1440,7 @@ mount_shortcut_cb (GtkMenuItem           *item,
 			    -1);
 
 	if (volume != NULL) {
-		nautilus_file_operations_mount_volume (NULL, volume);
+		nautilus_file_operations_mount_volume (NULL, volume, TRUE);
 		g_object_unref (volume);
 	}
 }
@@ -1948,9 +1960,10 @@ nautilus_places_sidebar_init (NautilusPlacesSidebar *sidebar)
 	g_signal_connect (tree_view, "button-press-event",
 			  G_CALLBACK (bookmarks_button_press_event_cb), sidebar);
 
-	eel_preferences_add_callback (NAUTILUS_PREFERENCES_CLICK_POLICY,
-				      click_policy_changed_callback,
-				      sidebar);
+	eel_preferences_add_callback_while_alive (NAUTILUS_PREFERENCES_CLICK_POLICY,
+						  click_policy_changed_callback,
+						  sidebar,
+						  G_OBJECT (sidebar));
 	update_click_policy (sidebar);
 
 	eel_preferences_add_callback_while_alive (NAUTILUS_PREFERENCES_DESKTOP_IS_HOME_DIR,
@@ -1965,12 +1978,15 @@ nautilus_places_sidebar_init (NautilusPlacesSidebar *sidebar)
 }
 
 static void
-nautilus_places_sidebar_finalize (GObject *object)
+nautilus_places_sidebar_dispose (GObject *object)
 {
 	NautilusPlacesSidebar *sidebar;
-	
+
 	sidebar = NAUTILUS_PLACES_SIDEBAR (object);
 
+	sidebar->window = NULL;
+	sidebar->tree_view = NULL;
+
 	g_free (sidebar->uri);
 	sidebar->uri = NULL;
 
@@ -1981,19 +1997,18 @@ nautilus_places_sidebar_finalize (GObject *object)
 		sidebar->store = NULL;
 	}
 
-	g_object_unref (sidebar->volume_monitor);
-	
-	eel_preferences_remove_callback (NAUTILUS_PREFERENCES_CLICK_POLICY,
-					 click_policy_changed_callback,
-					 sidebar);
+	if (sidebar->volume_monitor != NULL) {
+		g_object_unref (sidebar->volume_monitor);
+		sidebar->volume_monitor = NULL;
+	}
 
-	G_OBJECT_CLASS (nautilus_places_sidebar_parent_class)->finalize (object);
+	G_OBJECT_CLASS (nautilus_places_sidebar_parent_class)->dispose (object);
 }
 
 static void
 nautilus_places_sidebar_class_init (NautilusPlacesSidebarClass *class)
 {
-	G_OBJECT_CLASS (class)->finalize = nautilus_places_sidebar_finalize;
+	G_OBJECT_CLASS (class)->dispose = nautilus_places_sidebar_dispose;
 
 	GTK_WIDGET_CLASS (class)->style_set = nautilus_places_sidebar_style_set;
 }
