@@ -717,7 +717,6 @@ ensure_file_is_image (GFile *file)
 {
 	GFileInfo *info;
 	const char *mime_type;
-	gboolean ret;
 
 	info = g_file_query_info (file, G_FILE_ATTRIBUTE_STANDARD_CONTENT_TYPE, 0, NULL, NULL);
 	if (info == NULL) {
@@ -729,13 +728,11 @@ ensure_file_is_image (GFile *file)
 		return FALSE;
 	}
 
-	ret = (g_content_type_is_a (mime_type, "image/*") &&
-	       !g_content_type_equals (mime_type, "image/svg") &&
-	       !g_content_type_equals (mime_type, "image/svg+xml"));
-	
 	g_object_unref (info);
-	
-	return ret;
+
+	return  g_content_type_is_a (mime_type, "image/*") &&
+		!g_content_type_equals (mime_type, "image/svg") &&
+		!g_content_type_equals (mime_type, "image/svg+xml");
 }
 
 /* create the appropriate pixbuf for the passed in file */
@@ -760,7 +757,7 @@ make_drag_image (NautilusPropertyBrowser *property_browser, const char* file_nam
 			g_free (image_file_name);
 		} else {
 			icon_name = nautilus_emblem_get_icon_name_from_keyword (file_name);
-			info = nautilus_icon_info_lookup_from_name (icon_name, NAUTILUS_ICON_SIZE_STANDARD);
+			info = nautilus_icon_info_lookup_from_name (file_name, NAUTILUS_ICON_SIZE_STANDARD);
 			pixbuf = nautilus_icon_info_get_pixbuf_at_size (info, NAUTILUS_ICON_SIZE_STANDARD);
 			g_object_unref (info);
 			g_free (icon_name);
@@ -976,7 +973,7 @@ remove_pattern(NautilusPropertyBrowser *property_browser, const char* pattern_na
 
 	/* delete the pattern from the pattern directory */
 	if (g_unlink (pattern_path) != 0) {
-		char *message = g_strdup_printf (_("Sorry, but pattern %s couldn't be deleted."), pattern_name);
+		char *message = g_strdup_printf (_("Sorry, but pattern %s could not be deleted."), pattern_name);
 		char *detail = _("Check that you have permission to delete the pattern.");
 		eel_show_error_dialog (message, detail, GTK_WINDOW (property_browser));
 		g_free (message);
@@ -1005,7 +1002,7 @@ remove_emblem (NautilusPropertyBrowser *property_browser, const char* emblem_nam
 
 	/* delete the emblem from the emblem directory */
 	if (g_unlink (emblem_path) != 0) {
-		char *message = g_strdup_printf (_("Sorry, but emblem %s couldn't be deleted."), emblem_name);
+		char *message = g_strdup_printf (_("Sorry, but emblem %s could not be deleted."), emblem_name);
 		char *detail = _("Check that you have permission to delete the emblem.");
 		eel_show_error_dialog (message, detail, GTK_WINDOW (property_browser));
 		g_free (message);
@@ -1204,7 +1201,7 @@ add_pattern_to_browser (const char *path_name, gpointer *data)
 	/* don't allow the user to change the reset image */
 	basename = g_path_get_basename (path_name);
 	if (basename && eel_strcmp (basename, RESET_IMAGE_NAME) == 0) {
-		eel_show_error_dialog (_("Sorry, but you can't replace the reset image."), 
+		eel_show_error_dialog (_("Sorry, but you cannot replace the reset image."), 
 		                       _("Reset is a special image that cannot be deleted."), 
 		                       NULL);
 		g_free (path_uri);
@@ -1235,7 +1232,7 @@ add_pattern_to_browser (const char *path_name, gpointer *data)
 	if (!g_file_copy (src, dest,
 			  0,
 			  NULL, NULL, NULL, NULL)) {
-		char *message = g_strdup_printf (_("Sorry, but the pattern %s couldn't be installed."), path_name);
+		char *message = g_strdup_printf (_("Sorry, but the pattern %s could not be installed."), path_name);
 		eel_show_error_dialog (message, NULL, GTK_WINDOW (property_browser));
 		g_free (message);
 	}
